#!/usr/bin/env python
import shlex,sys,json
import numpy as np

from PyFoam.RunDictionary.SolutionDirectory import SolutionDirectory
from PyFoam.Basics.TemplateFile import TemplateFile
from PyFoam.Basics.DataStructures import Vector
from PyFoam.RunDictionary.ParsedParameterFile import ParsedParameterFile
from PyFoam.Execution.BasicRunner import BasicRunner
from PyFoam.Error import error


def main():
	#cavity case set
	cavityCase=SolutionDirectory("./cavity")

	#result list
	results=[]
	#blockMeshTemplate
	bMDictTemp=TemplateFile(cavityCase.blockMesh() + ".template",expressionDelimiter="$")
	#0/U 
	U=ParsedParameterFile(cavityCase.initialDir() + "/U")

	for blockL in [1,2]:
		for blockH in [1,2]:
			for Uwall in [0.5, 1.0]:

				#clear case
				cavityCase.clear()

				#edit files
				bMDictTemp.writeToFile(cavityCase.blockMesh(),{"L":blockL,"H":blockH})
				U['boundaryField']['movingWall']['value'].setUniform(Vector(Uwall,0,0))
				U.writeFile()
				
				#blockMesh
				args=shlex.split("blockMesh -case " + cavityCase.name)
				block=BasicRunner(args,silent=True)
				block.start()
				if not block.runOK():
					error("There was a problem with blockMesh")
					sys.exit(1)

				#icoFoam
				args=shlex.split("icoFoam -case " + cavityCase.name)
				ico=BasicRunner(args,silent=True)
				ico.start()
				if not ico.runOK():
					error("There was a problem with icoFoam")
					sys.exit(1)

				#post
				p_latest=ParsedParameterFile(cavityCase.latestDir() + '/p')
				pmax=np.array(p_latest['internalField'].val).max()
				
				#append results
				results.append({"L":blockL,"H":blockH,"Uwall":Uwall,"pmax":pmax})
				
	#print results
	print json.dumps(results,indent=4)


if __name__ == '__main__':
    main()
